@@ -1,4 +1,5 @@
-from perfect_information_game.utils import get_training_path, ActiveGame as GameClass
+from perfect_information_game.utils import get_training_path
+from perfect_information_game.games import Chess as GameClass
 from perfect_information_game.move_selection import RawNetwork
 from perfect_information_game.move_selection.mcts import AsyncMCTS
 from perfect_information_game.heuristics import Network
